==========
References
==========

This section contains reference materials for Ironic, including API documentation, CLI tools, configuration details, and more.

Drivers, Hardware Types, and Hardware Interfaces
------------------------------------------------
:doc:`Drivers, Hardware Types, and Hardware Interfaces </admin/index>`

Configuration Reference
-----------------------
:doc:`Configuration Reference </configuration/index>`

API Reference
-------------
`API Reference <https://docs.openstack.org/api-ref/baremetal/>`_

CLI References
--------------
- `Ironic CLI <https://docs.openstack.org/python-ironicclient/latest/cli/>`_
- :doc:`ironic-dbsync </cli/ironic-dbsync>`
- `ironic-status <https://docs.openstack.org/ironic/latest/cli/ironic-status.html>`_

Trait Based Networking Reference
--------------------------------

.. toctree::
   :maxdepth: 1

   TBN Configuration File <trait-based-networking/tbn-config-file>
   Filter Expression Reference <trait-based-networking/filter-expression-reference>
